@@ -1,17 +1,17 @@
-import requests
+import requests as requests_http
 from . import utils
 from speakeasy.models import operations, shared
 from typing import Optional
 
 class Embeds:
-    _client: requests.Session
-    _security_client: requests.Session
+    _client: requests_http.Session
+    _security_client: requests_http.Session
     _server_url: str
     _language: str
     _sdk_version: str
     _gen_version: str
 
-    def __init__(self, client: requests.Session, security_client: requests.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
+    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
         self._client = client
         self._security_client = security_client
         self._server_url = server_url
@@ -30,7 +30,7 @@ class Embeds:
         url = base_url.removesuffix('/') + '/v1/workspace/embed-access-token'
         
         headers = {}
-        query_params = utils.get_query_params(request.query_params)
+        query_params = utils.get_query_params(operations.GetEmbedAccessTokenRequest, request)
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
         
         client = self._security_client
@@ -86,7 +86,7 @@ class Embeds:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/workspace/embed-access-tokens/{tokenID}', request.path_params)
+        url = utils.generate_url(operations.RevokeEmbedAccessTokenRequest, base_url, '/v1/workspace/embed-access-tokens/{tokenID}', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
