@@ -7,17 +7,12 @@ from typing import Optional
 
 
 @dataclasses.dataclass
-class FindAPIEndpointPathParams:
+class FindAPIEndpointRequest:
     api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     display_name: str = dataclasses.field(metadata={'path_param': { 'field_name': 'displayName', 'style': 'simple', 'explode': False }})
     version_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'versionID', 'style': 'simple', 'explode': False }})
     
 
-@dataclasses.dataclass
-class FindAPIEndpointRequest:
-    path_params: FindAPIEndpointPathParams = dataclasses.field()
-    
-
 @dataclasses.dataclass
 class FindAPIEndpointResponse:
     content_type: str = dataclasses.field()
