@@ -7,16 +7,11 @@ from typing import Optional
 
 
 @dataclasses.dataclass
-class GenerateOpenAPISpecPathParams:
+class GenerateOpenAPISpecRequest:
     api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     version_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'versionID', 'style': 'simple', 'explode': False }})
     
 
-@dataclasses.dataclass
-class GenerateOpenAPISpecRequest:
-    path_params: GenerateOpenAPISpecPathParams = dataclasses.field()
-    
-
 @dataclasses.dataclass
 class GenerateOpenAPISpecResponse:
     content_type: str = dataclasses.field()
