@@ -1,6 +1,6 @@
 from __future__ import annotations
 import dataclasses
-import requests
+import requests as requests_http
 from ..shared import api as shared_api
 from ..shared import error as shared_error
 from typing import Optional
@@ -12,21 +12,16 @@ class GetApisOp:
     
 
 @dataclasses.dataclass
-class GetApisQueryParams:
+class GetApisRequest:
     metadata: Optional[dict[str, list[str]]] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'metadata', 'style': 'deepObject', 'explode': True }})
     op: Optional[GetApisOp] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'op', 'style': 'deepObject', 'explode': True }})
     
 
-@dataclasses.dataclass
-class GetApisRequest:
-    query_params: GetApisQueryParams = dataclasses.field()
-    
-
 @dataclasses.dataclass
 class GetApisResponse:
     content_type: str = dataclasses.field()
     status_code: int = dataclasses.field()
     apis: Optional[list[shared_api.API]] = dataclasses.field(default=None)
     error: Optional[shared_error.Error] = dataclasses.field(default=None)
-    raw_response: Optional[requests.Response] = dataclasses.field(default=None)
+    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
     
\ No newline at end of file
